@@ -37,10 +37,10 @@ class Address:
             tel: STR
             email: STR
             organisation: STR
-            address1: STR
-            address2: STR
-            address3: STR
-            address4: STR
+            address1: STR  (street)
+            address2: STR  (locality)
+            address3: STR  (town)
+            address4: STR  (county)
             postcode : STR
 
         Must has minimum of:
@@ -90,10 +90,10 @@ class Parcel(Address):
             tel: STR
             email: STR
             organisation: STR
-            address1: STR
-            address2: STR
-            address3: STR
-            address4: STR
+            address1: STR  (street)
+            address2: STR  (locality)
+            address3: STR  (town)
+            address4: STR   (county)
             postcode : STR
             shipping ref: STR
             delivery instructions: STR
@@ -520,8 +520,8 @@ class DPD:
                             "countryCode": "GB",
                             "postcode": self.sender_address.postcode,
                             "street": self.sender_address.address_1,
-                            "locality": self.sender_address.address_2 if not self.sender_address.address_3 == "" else "",
-                            "town": self.sender_address.address_2 if self.sender_address.address_3 == "" else self.sender_address.address_3,
+                            "locality": self.sender_address.address_2,
+                            "town": self.sender_address.address_3,
                             "county": self.sender_address.address_4,
                         }
                     },
@@ -531,7 +531,7 @@ class DPD:
                             "telephone": parcel.tel
                         },
                         "address": {
-                            "organisation": parcel.name,
+                            "organisation": parcel.name if not parcel.organisation else parcel.name if parcel.name else "Shipment",
                             "countryCode": "GB",
                             "postcode": parcel.postcode,
                             "street": parcel.address_1,
